import { join } from 'path';
import { existsSync, readdirSync, lstatSync } from 'fs';

/**
 * @description 是否是文件夹
 * @param path
 * @returns
 */
const isDir = (path) => {
    return lstatSync(path).isDirectory();
};
/**
 * @description 是否存在文件
 * @param path
 * @returns
 */
const hasFile = (path) => {
    return existsSync(path);
};
/**
 * @description 获取所有文件夹
 * @param path
 * @returns
 */
const getDirs = (path) => {
    try {
        const dirs = readdirSync(path);
        return dirs.reduce((result, name) => {
            const fullPath = join(path, name);
            isDir(fullPath) && result.push({ dirName: name, dirPath: fullPath });
            return result;
        }, []);
    }
    catch (error) {
        throw new Error(error);
    }
};

function genAlias(root) {
    const dirs = getDirs(root);
    return dirs.reduce((result, item) => {
        const key = `@${item.dirName}`;
        const value = item.dirPath;
        result[key] = value;
        return result;
    }, {});
}
function alias(api) {
    const cwd = api.getCwd();
    const root = join(cwd, 'src');
    if (!hasFile(root)) {
        return;
    }
    api.configureWebpack(config => {
        const baseAlias = config.resolve?.alias || {};
        return {
            resolve: {
                alias: { ...genAlias(root), ...baseAlias }
            }
        };
    });
}

export { alias as default };
